
# Domains
This section examines coverage and performance across task types in SEB. The domains follows the categories used in the [Universal Dependencies project](https://universaldependencies.org).

# Performance across Domains
The table show the performance across domains in the Scandinavian Embedding Benchmark.

<iframe title="Domains SEB" aria-label="Table" id="datawrapper-chart-F00q5" src="https://datawrapper.dwcdn.net/F00q5/10/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="1043" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r=0;r<e.length;r++)if(e[r].contentWindow===a.source){var i=a.data["datawrapper-height"][t]+"px";e[r].style.height=i}}}))}();
</script>


## Coverage
The following table show the coverage pr. language. Note that some are only partially includes. This is due to some text partially including data from the domain though it is not considered the majority.

|             |                 Across                 |                Danish                |          Norwegian Bokmål          |         Norwegian Nynorsk          |              Swedish               |
| ----------- | :------------------------------------: | :----------------------------------: | :--------------------------------: | :--------------------------------: | :--------------------------------: |
| **Domain**  |                                        |                                      |                                    |                                    |                                    |
| Academic    |  (<span style="color:green">✓</span>)  | (<span style="color:green">✓</span>) |                                    |                                    |                                    |
| Bible       |                                        |                                      |                                    |                                    |                                    |
| Blog        |                                        |                                      |                                    |                                    |                                    |
| Fiction     |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |
| Government  |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |
| Legal       |   <span style="color:green">✓</span>   | (<span style="color:green">✓</span>) | <span style="color:green">✓</span> | <span style="color:green">✓</span> |                                    |
| Medical     |                                        |                                      |                                    |                                    |                                    |
| News        |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
| Non-Fiction |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
| Poetry      | ( <span style="color:green">✓</span> ) | (<span style="color:green">✓</span>) |                                    |                                    |                                    |
| Reviews     |   <span style="color:green">✓</span>   |                                      | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
| Social      |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  |                                    |                                    | <span style="color:green">✓</span> |
| Spoken      |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
| Wiki        |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |
| Web         |   <span style="color:green">✓</span>   |  <span style="color:green">✓</span>  |                                    |                                    | <span style="color:green">✓</span> |





